@@ -57,6 +57,7 @@ are dynamically loaded by Watcher at launch time.
 
 import datetime
 
+from http import HTTPStatus
 import pecan
 from pecan import rest
 import wsme
@@ -117,9 +118,9 @@ class Action(base.APIBase):
     uuid = wtypes.wsattr(types.uuid, readonly=True)
     """Unique UUID for this action"""
 
-    action_plan_uuid = wsme.wsproperty(types.uuid, _get_action_plan_uuid,
-                                       _set_action_plan_uuid,
-                                       mandatory=True)
+    action_plan_uuid = wtypes.wsproperty(types.uuid, _get_action_plan_uuid,
+                                         _set_action_plan_uuid,
+                                         mandatory=True)
     """The action plan this action belongs to """
 
     state = wtypes.text
@@ -137,7 +138,7 @@ class Action(base.APIBase):
     parents = wtypes.wsattr(types.jsontype, readonly=True)
     """UUIDs of parent actions"""
 
-    links = wsme.wsattr([link.Link], readonly=True)
+    links = wtypes.wsattr([link.Link], readonly=True)
     """A list containing a self link and associated action links"""
 
     def __init__(self, **kwargs):
@@ -362,7 +363,7 @@ class ActionsController(rest.RestController):
 
         return Action.convert_with_links(action)
 
-    @wsme_pecan.wsexpose(Action, body=Action, status_code=201)
+    @wsme_pecan.wsexpose(Action, body=Action, status_code=HTTPStatus.CREATED)
     def post(self, action):
         """Create a new action(forbidden).
 
@@ -422,7 +423,7 @@ class ActionsController(rest.RestController):
         action_to_update.save()
         return Action.convert_with_links(action_to_update)
 
-    @wsme_pecan.wsexpose(None, types.uuid, status_code=204)
+    @wsme_pecan.wsexpose(None, types.uuid, status_code=HTTPStatus.NO_CONTENT)
     def delete(self, action_uuid):
         """Delete a action(forbidden).
 
