@@ -19,8 +19,6 @@ Service mechanism provides ability to monitor Watcher services state.
 """
 
 import datetime
-import six
-
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import timeutils
@@ -70,7 +68,7 @@ class Service(base.APIBase):
         service = objects.Service.get(pecan.request.context, id)
         last_heartbeat = (service.last_seen_up or service.updated_at or
                           service.created_at)
-        if isinstance(last_heartbeat, six.string_types):
+        if isinstance(last_heartbeat, str):
             # NOTE(russellb) If this service came in over rpc via
             # conductor, then the timestamp will be a string and needs to be
             # converted back to a datetime.
