@@ -13,6 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from operator import attrgetter
+
 import jsonpatch
 from oslo_config import cfg
 from oslo_utils import reflection
@@ -21,6 +23,7 @@ import pecan
 import wsme
 
 from watcher._i18n import _
+from watcher.api.controllers.v1 import versions
 from watcher.common import utils
 from watcher import objects
 
@@ -54,6 +57,13 @@ def validate_sort_dir(sort_dir):
                                          "'asc' or 'desc'") % sort_dir)
 
 
+def validate_sort_key(sort_key, allowed_fields):
+    # Very lightweight validation for now
+    if sort_key not in allowed_fields:
+        raise wsme.exc.ClientSideError(
+            _("Invalid sort key: %s") % sort_key)
+
+
 def validate_search_filters(filters, allowed_fields):
     # Very lightweight validation for now
     # todo: improve this (e.g. https://www.parse.com/docs/rest/guide/#queries)
@@ -63,6 +73,19 @@ def validate_search_filters(filters, allowed_fields):
                 _("Invalid filter: %s") % filter_name)
 
 
+def check_need_api_sort(sort_key, additional_fields):
+    return sort_key in additional_fields
+
+
+def make_api_sort(sorting_list, sort_key, sort_dir):
+    # First sort by uuid field, than sort by sort_key
+    # sort() ensures stable sorting, so we could
+    # make lexicographical sort
+    reverse_direction = (sort_dir == 'desc')
+    sorting_list.sort(key=attrgetter('uuid'), reverse=reverse_direction)
+    sorting_list.sort(key=attrgetter(sort_key), reverse=reverse_direction)
+
+
 def apply_jsonpatch(doc, patch):
     for p in patch:
         if p['op'] == 'add' and p['path'].count('/') == 1:
@@ -79,6 +102,18 @@ def get_patch_value(patch, key):
             return p['value']
 
 
+def set_patch_value(patch, key, value):
+    for p in patch:
+        if p['op'] == 'replace' and p['path'] == '/%s' % key:
+            p['value'] = value
+
+
+def get_patch_key(patch, key):
+    for p in patch:
+        if p['op'] == 'replace' and key in p.keys():
+            return p[key][1:]
+
+
 def check_audit_state_transition(patch, initial):
     is_transition_valid = True
     state_value = get_patch_value(patch, "state")
@@ -121,3 +156,41 @@ def get_resource(resource, resource_id, eager=False):
         return _get(pecan.request.context, resource_id, eager=eager)
 
     return _get(pecan.request.context, resource_id)
+
+
+def allow_start_end_audit_time():
+    """Check if we should support optional start/end attributes for Audit.
+
+    Version 1.1 of the API added support for start and end time of continuous
+    audits.
+    """
+    return pecan.request.version.minor >= (
+        versions.VERSIONS.MINOR_1_START_END_TIMING.value)
+
+
+def allow_force():
+    """Check if we should support optional force attribute for Audit.
+
+    Version 1.2 of the API added support for forced audits that allows to
+    launch audit when other action plan is ongoing.
+    """
+    return pecan.request.version.minor >= (
+        versions.VERSIONS.MINOR_2_FORCE.value)
+
+
+def allow_list_datamodel():
+    """Check if we should support list data model API.
+
+    Version 1.3 of the API added support to list data model.
+    """
+    return pecan.request.version.minor >= (
+        versions.VERSIONS.MINOR_3_DATAMODEL.value)
+
+
+def allow_webhook_api():
+    """Check if we should support webhook API.
+
+    Version 1.4 of the API added support to trigger webhook.
+    """
+    return pecan.request.version.minor >= (
+        versions.VERSIONS.MINOR_4_WEBHOOK_API.value)
