@@ -18,18 +18,32 @@
 
 from oslo_config import cfg
 
+from watcher.common import clients
+
 nova_client = cfg.OptGroup(name='nova_client',
                            title='Configuration Options for Nova')
 
 NOVA_CLIENT_OPTS = [
     cfg.StrOpt('api_version',
-               default='2',
-               help='Version of Nova API to use in novaclient.'),
+               default='2.56',
+               help="""
+Version of Nova API to use in novaclient.
+
+Minimum required version: %s
+
+Certain Watcher features depend on a minimum version of the compute
+API being available which is enforced with this option. See
+https://docs.openstack.org/nova/latest/reference/api-microversion-history.html
+for the compute API microversion history.
+""" % clients.MIN_NOVA_API_VERSION),
     cfg.StrOpt('endpoint_type',
                default='publicURL',
-               help='Type of endpoint to use in novaclient.'
-                    'Supported values: internalURL, publicURL, adminURL'
-                    'The default is publicURL.')]
+               help='Type of endpoint to use in novaclient. '
+                    'Supported values: internalURL, publicURL, adminURL. '
+                    'The default is publicURL.'),
+    cfg.StrOpt('region_name',
+               help='Region in Identity service catalog to use for '
+                    'communication with the OpenStack service.')]
 
 
 def register_opts(conf):
@@ -38,4 +52,4 @@ def register_opts(conf):
 
 
 def list_opts():
-    return [('nova_client', NOVA_CLIENT_OPTS)]
+    return [(nova_client, NOVA_CLIENT_OPTS)]
