@@ -63,6 +63,9 @@ class BaremetalClusterDataModelCollector(base.BaseClusterDataModelCollector):
         if self._audit_scope_handler is None:
             LOG.debug("No audit, Don't Build Baremetal data model")
             return
+        if self._data_model_scope is None:
+            LOG.debug("No audit scope, Don't Build Baremetal data model")
+            return
 
         builder = BareMetalModelBuilder(self.osc)
         return builder.execute(self._data_model_scope)
@@ -78,6 +81,7 @@ class BareMetalModelBuilder(base.BaseModelBuilder):
     def __init__(self, osc):
         self.osc = osc
         self.model = model_root.BaremetalModelRoot()
+        # TODO(lpetrut): add MAAS support
         self.ironic_helper = ironic_helper.IronicHelper(osc=self.osc)
 
     def add_ironic_node(self, node):
