@@ -17,8 +17,6 @@
 # limitations under the License.
 #
 
-from __future__ import division
-
 from oslo_log import log
 
 from watcher._i18n import _
@@ -297,7 +295,7 @@ class WorkloadBalance(base.WorkloadStabilizationBaseStrategy):
                         self.threshold)
             return self.solution
 
-        # choose the server with largest cpu_util
+        # choose the server with largest cpu usage
         source_nodes = sorted(source_nodes,
                               reverse=True,
                               key=lambda x: (x[self._meter]))
