@@ -10,9 +10,10 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
+from http import HTTPStatus
 from oslo_config import cfg
 from oslo_serialization import jsonutils
-from six.moves.urllib import parse as urlparse
+from urllib import parse as urlparse
 
 from watcher.tests.api import base as api_base
 from watcher.tests.objects import utils as obj_utils
@@ -57,7 +58,7 @@ class TestListService(api_base.FunctionalTest):
         response = self.get_json(
             '/services/%s' % service['id'],
             expect_errors=True)
-        self.assertEqual(404, response.status_int)
+        self.assertEqual(HTTPStatus.NOT_FOUND, response.status_int)
 
     def test_detail(self):
         service = obj_utils.create_test_service(self.context)
@@ -74,7 +75,7 @@ class TestListService(api_base.FunctionalTest):
         service = obj_utils.create_test_service(self.context)
         response = self.get_json('/services/%s/detail' % service.id,
                                  expect_errors=True)
-        self.assertEqual(404, response.status_int)
+        self.assertEqual(HTTPStatus.NOT_FOUND, response.status_int)
 
     def test_many(self):
         service_list = []
@@ -131,6 +132,26 @@ class TestListService(api_base.FunctionalTest):
         response = self.get_json('/services')
         self.assertEqual(3, len(response['services']))
 
+    def test_many_with_sort_key_name(self):
+        service_list = []
+        for id_ in range(1, 4):
+            service = obj_utils.create_test_service(
+                self.context, id=id_, host='CONTROLLER',
+                name='SERVICE_{0}'.format(id_))
+            service_list.append(service.name)
+
+        response = self.get_json('/services/?sort_key=name')
+
+        self.assertEqual(3, len(response['services']))
+        names = [s['name'] for s in response['services']]
+        self.assertEqual(sorted(service_list), names)
+
+    def test_sort_key_validation(self):
+        response = self.get_json(
+            '/services?sort_key=%s' % 'bad_name',
+            expect_errors=True)
+        self.assertEqual(HTTPStatus.BAD_REQUEST, response.status_int)
+
 
 class TestServicePolicyEnforcement(api_base.FunctionalTest):
 
@@ -140,7 +161,7 @@ class TestServicePolicyEnforcement(api_base.FunctionalTest):
             "default": "rule:admin_api",
             rule: "rule:default"})
         response = func(*arg, **kwarg)
-        self.assertEqual(403, response.status_int)
+        self.assertEqual(HTTPStatus.FORBIDDEN, response.status_int)
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(
             "Policy doesn't allow %s to be performed." % rule,
